function xk=M92newton_system(P,eps,MAX)
% Numeric solution of system of nonlinear equations
% Equation1: f(x,y)=x^2-2*x-y+0.5=0
% Equation2: g(x,y)=x^2+4*y^2-4=0
%  P  - initial approximation
%  eps - accuracy
%  M   - maximum number of iterations
  if exist('P')==0
    P=[4 2]'; eps=1e-12; M=40; PG=P;
  end
  for k=2:M
      DF=J(P); F=[-f(P); -g(P)];
      DP=inv(DF)*F;
      P=P+DP; PG=[PG P];
      if abs(sum(DP))<eps, break, end
  end
  xk=P(:,end);
  plot(PG'); grid on; title('SOLUTION EVOLUTION')
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function z=f(P)
  x=P(1); y=P(2);
  z=x^2-2*x-y+0.5;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function z=g(P)
  x=P(1); y=P(2);
  z=x^2+4*y^2-4;
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function W=J(P)
  x=P(1); y=P(2);
  W=[(2*x-2) (-1);
     (2*x) (8*y)]; 
  
